@@ -27,3 +27,7 @@ class TestGCProductCategories(TestCase):
 
         self.assertIsInstance(GameController.GCProductCategoryMouse, str)
         self.assertIsInstance(GameController.GCProductCategoryKeyboard, str)
+
+    @min_os_level("13.0")
+    def test_constants13_0(self):
+        self.assertIsInstance(GameController.GCProductCategoryHID, str)
